%     Ventricular action potential model ORdmJ
%     Copyright (C) 2020 Jordi Llopis. Contact: jorllolo@etsii.upv.es
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function [Tqnet, Ttriang, output] = calculate_TqNet_Ttriang(parameters)
% This function calculates Tqnet and Ttriang for a given drug. It is
% assumed that concentration stored in parameters.D is the EFTPC.
% INPUTS:
% parameters: a structure array containing numbers of beats of the
% simulation, cycle length, initial conditions, cell type, drug
% concentration...
% OUTPUTS:
% Tqnet: value of the index Tqnet
% Ttriang: value of the index Ttirang
% output: a structure array containeg time vector, state variable and
% currents correspondig to the last beat simulated under 10 times the
% concentration indicated in parameters.D)

parameters.D = parameters.D*10; % Drug concentration is multiplied by 10
% becasue of the definition of Tqnet and Ttriang. Then the model is ran
% again with this new concentration.
[time,X, IsJs] = modelRunner(parameters);
output.time=time;
output.X=X;
output.IsJs=IsJs;

%%%%%%%%%%%%%%%%%%%%%%%%%%%% TqNet %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
I=IsJs(:,2:7)';
t=time(:)';
Inet=sum(I);
qnet=cumtrapz(t/1000, Inet);

qnetControl=0.050041561464086; % qnetControl for celltype='endo', beats= 1000 beats, CL=1000 ms
Tqnet=qnet(end)/qnetControl;

%%%%%%%%%%%%%%%%%%%%%%%%%%%% Ttriang %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
triangControl=91.114765356894620; % triangControl for celltype='endo', beats= 1000 beats, CL=1000 ms
[APD90,~,~,~,~,~]=APD(t,X(:,1),90);
[APD30,~,~,~,~,~]=APD(t,X(:,1),30);
Ttriang=(APD90-APD30)/triangControl;
end