%     Ventricular action potential model ORdmJ
%     Copyright (C) 2020 Jordi Llopis. Contact: jorllolo@etsii.upv.es
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

%% This is a simple script which simulates 1000 beats for the endocardial 
%% model under a certain drug concentration and computes Tx, TqNet, Ttriang
%% and TEAD
% Setting parameters
clear 
% Parameters is the structure of model parameters that the user may wish to
% change compared to default simulation. It mainly includes cell type,
% number of beats, cycle length, drug concentration, pharmacological data
% (IC50 and Hill coefficient)
parameters.beats= 1000; % number of beats
parameters.CL= 1000; % cycle length in ms
parameters.celltype= 'endo'; % possible cellType values: 'endo', 'epi', 'mid'
load('X0.mat'); % loading the file with the inital conditions
parameters.X0=X0; % initials conditions
parameters.options=[];% parameters for ode solver - usually empty

parameters.D=3.5; % Drug concentration to be tested. For computtation of biomarkers it is considered as EFTPC
parameters.ICNa=[]; % IC 50 for INa channel
parameters.hNa=[]; % Hill coefficient for INa channel
parameters.ICNaL=[]; % IC 50 for INaL channel
parameters.hNaL=[]; % Hill coefficient for INaL channel
parameters.ICto=[]; % IC 50 for Ito channel
parameters.hto=[]; % Hill coefficient for Ito channel
parameters.ICCaL=[]; % IC 50 for ICaL channel
parameters.hCaL=[]; % Hill coefficient for ICaL channel
parameters.ICKr=25; % IC 50 for IKr channel
parameters.hKr=[]; % Hill coefficient for IKr channel
parameters.ICKs=[]; % IC 50 for IKs channel
parameters.hKs=[]; % Hill coefficient for IKs channel
parameters.ICK1=[]; % IC 50 for IK1 channel
parameters.hK1=[]; % Hill coefficient for IK1 channel

%% Simulation of drug effect at the drug concentration specified and 
%% calculation of arrhythmogenic indices
% The structure parameters is passed to modelRunner, which is
% an interface between user and the simulation code itself. 
[time_initial_D, X_initial_D,IsJs_inital_D] = modelRunner(parameters);

% Tqnet and Ttriang are obtained
% output_concentration_10times is an structure array containing time vector,
% state variable and currents correspondig to the last beat simulated under
% 10 times EFTPC (that is 10 times the concentration indicated in
% parameters.D)
[Tqnet, Ttriang, output_concentration_10times] = calculate_TqNet_Ttriang(parameters);

% Tx is computed
% Tx_ev is a vector containing the values of [] / EFTPC for the different
% concentrations tested from initial drug concentration (assumed to be
% EFTPC)
% output_concentration_Tx  is an structure array containing time vector,
% state variable and currents correspondig to the last beat simulated under
% concentration that prolongs APD90 a 10%
[Tx, Tx_ev, output_concentration_Tx] = calculate_Tx(parameters, time_initial_D, X_initial_D(:,1));

% TEAD calculation
% output_EAD  is an structure array containing time vector,
% state variable and currents correspondig to the last 3 beat simulated
% under drug concentration leading to an EAD
[ TEAD, output_EAD] = calculate_TEAD(parameters);
